@@ -156,11 +156,7 @@ class CacheWorkspace:
         '''
         out, err = waitfor(
             self.ws.ws_allocate(
-                self.id,
-                str(self.expire_in_days),
-                '-c',
-                'temporary_files'),
-            discard_output=False)
+                self.id, str(self.expire_in_days), '-c', 'temporary_files'))
         self.name = out.strip()
 
     def cleanup(self) -> None:
